@@ -31,14 +31,16 @@ try:
     import storage
     import util
     from config import *
+    import debuglog
 except:
     from sabayon import userprofile
     from sabayon import storage
     from sabayon import util
     from sabayon.config import *
+    from sabayon import debuglog
 
 def dprint (fmt, *args):
-    util.debug_print (util.DEBUG_GCONFSOURCE, fmt % args)
+    debuglog.debug_log (False, debuglog.DEBUG_LOG_DOMAIN_GCONF_SOURCE, fmt % args)
 
 # gconf_engine_associate_schema() isn't wrapped
 def associate_schema (config_source, key, schema_key):
@@ -334,13 +336,26 @@ class GConfSource (userprofile.ProfileSource):
             return True
         return False
 
+    def set_value (self, key, gconf_value, mandatory):
+        change = GConfChange (self, key, gconf_value)
+        change.set_mandatory (mandatory)
+        self.client.set (key, gconf_value)
+        self.emit_change (change)
+
     def set_gconf_boolean (self, key, value, mandatory):
         gconf_value = gconf.Value (gconf.VALUE_BOOL)
         gconf_value.set_bool (value)
-        change = GConfChange (self, key, gconf_value)
-        change.set_mandatory (mandatory)
-        self.client.set_bool (key, value)
-        self.emit_change (change)
+        self.set_value (key, gconf_value, mandatory);
+
+    def set_gconf_int (self, key, value, mandatory):
+        gconf_value = gconf.Value (gconf.VALUE_INT)
+        gconf_value.set_int (value)
+        self.set_value (key, gconf_value, mandatory);
+
+    def set_gconf_string (self, key, value, mandatory):
+        gconf_value = gconf.Value (gconf.VALUE_STRING)
+        gconf_value.set_string (value)
+        self.set_value (key, gconf_value, mandatory);
 
     def set_gconf_list (self, key, list_type, value, mandatory):
         gconf_value = gconf.Value (gconf.VALUE_LIST)
@@ -354,10 +369,7 @@ class GConfSource (userprofile.ProfileSource):
             list.append (item_value)
         gconf_value.set_list_type (list_type)
         gconf_value.set_list (list)
-        change = GConfChange (self, key, gconf_value)
-        change.set_mandatory (mandatory)
-        self.client.set_list (key, list_type, value)
-        self.emit_change (change)
+        self.set_value (key, gconf_value, mandatory);
 
 gobject.type_register (GConfSource)
 
